# Geographical data

The data files in this folder contain the mappings needed to convert between postcodes, local authority codes and local authority names.

## Postcode mappings

The postcode-LA code and name lookup tables are taken from the [National Statistics Postcode Lookup](https://geoportal.statistics.gov.uk/datasets/4f71f3e9806d4ff895996f832eb7aacf/about) dataset.

## LA decodes

The LA-code to LA-name mappings are taken from the open data portal on gov.uk, available [here](https://data.gov.uk/dataset/24d87ad2-0fa9-4b35-816a-89f9d92b0042/local-authority-districts-april-2020-names-and-codes-in-the-united-kingdom).
